@@ -1,6 +1,9 @@
 import shutil
 import sys, os, time, json
 import argparse
+
+from manafa.am_emanafa import AMEManafa
+from manafa.services.perfettoService import convert_to_systrace
 from manafa.utils.Utils import execute_shell_command, mega_find, get_resources_dir
 from manafa.emanafa import EManafa
 from manafa.hunter_emanafa import HunterEManafa
@@ -30,6 +33,9 @@ def create_manafa(args):
         return HunterEManafa(power_profile=args.profile, timezone=args.timezone, resources_dir=MANAFA_RESOURCES_DIR,
             instrument_file=TO_INSTRUMENT_FILE,
             not_instrument_file=NOT_INSTRUMENT_FILE)
+    elif not args.hunter and args.app_package is not None:
+        return AMEManafa(app_package_name=args.app_package, power_profile=args.profile, timezone=args.timezone,
+                         resources_dir=MANAFA_RESOURCES_DIR)
     else:
         return EManafa(power_profile=args.profile, timezone=args.timezone, resources_dir=MANAFA_RESOURCES_DIR)
 
@@ -39,14 +45,19 @@ def parse_results(args, manafa):
         bstats_files = mega_find(args.directory, pattern="bstats-*", maxdepth=2, type_file='f')
         for b_file in bstats_files:
             b_file_id = os.path.basename(b_file).split("-")[1] #if len(os.path.basename(b_file).split("-")) >
-            matching_pft_files = [ x for x in  mega_find(args.directory, pattern="trace-*" ) if b_file_id in x ]
+            matching_pft_files = [x for x in mega_find(args.directory, pattern="trace-*") if b_file_id in x]
             if len(matching_pft_files) == 0:
                 print(" unmatched batstats file")
                 continue
+
+            is_converted = matching_pft_files[0].endswith('.systrace')
+            if not is_converted:
+                matching_pft_files[0] = convert_to_systrace(matching_pft_files[0])
             matching_ht_files = [x for x in mega_find(args.directory, pattern="hunter-*") if b_file_id in x]
             if len(matching_ht_files) > 0:
                 _, fc = manafa.parse_results(bts_file=b_file, pf_file=matching_pft_files[0], htr_file=matching_ht_files[0])
-                shutil.copyfile(fc, os.path.basename(fc))
+                if fc is not None:
+                    shutil.copyfile(fc, os.path.basename(fc))
             else:
                 manafa.parse_results(b_file, matching_pft_files[0])
             begin = manafa.perf_events.events[0].time if len(manafa.perf_events.events) > 1 else manafa.bat_events.events[0].time
@@ -77,7 +88,7 @@ def print_profiled_stats(el_time, total_consumption, per_comp_consumption, event
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("-ht", "--hunter", help="parse hunter logs", action='store_true', default=True)
+    parser.add_argument("-ht", "--hunter", help="parse hunter logs", action='store_true', default=False)
     parser.add_argument("-p", "--profile", help="power profile file", default=None, type=str)
     parser.add_argument("-t", "--timezone", help="device timezone", default=None, type=str)
     parser.add_argument("-pft", "--perfettofile", help="perfetto file", default=None, type=str)
@@ -86,6 +97,8 @@ def main():
     parser.add_argument("-d", "--directory", help="results file directory", default=None, type=str)
     parser.add_argument("-o", "--output_file", help="output file", default=None, type=str)
     parser.add_argument("-s", "--time_in_secs", help="time to profile", default=0, type=int)
+    parser.add_argument("-a", "--app_package", help="package of app to profile", default=None, type=str)
+
     args = parser.parse_args()
     has_device_conn = has_connected_devices()
     invalid_file_args = (args.perfettofile is None or args.batstatsfile is None) and args.directory is None
@@ -96,6 +109,7 @@ def main():
     manafa = create_manafa(args)
     if has_device_conn and invalid_file_args:
         manafa.init()
+        print('paco')
         manafa.start()
         log("profiling...")
         if args.time_in_secs == 0:
@@ -106,6 +120,7 @@ def main():
             time.sleep(args.time_in_secs)  # do work
             log("stopping profiler...")
         manafa.stop()
+        manafa.clean()
         begin = manafa.perf_events.events[0].time if len(manafa.perf_events.events) > 1 else manafa.bat_events.events[0].time
         end = manafa.perf_events.events[-1].time if len(manafa.perf_events.events) > 1 else manafa.bat_events.events[-1].time
         total, per_c, timeline = manafa.get_consumption_in_between(begin, end)
