@@ -1,6 +1,26 @@
 import os
 from subprocess import Popen, PIPE
-from textops import find
+import fnmatch
+
+
+def find_files_with_pattern(basedir, pattern, context=None, only_files=False, only_dirs=False):
+    matches = []
+    for root, dirs, files in os.walk(basedir):
+        if only_files and only_dirs:
+            break
+        for name in files + dirs:
+            full_path = os.path.join(root, name)
+            if fnmatch.fnmatch(name, pattern):
+                if only_files and os.path.isfile(full_path):
+                    matches.append(full_path)
+                elif only_dirs and os.path.isdir(full_path):
+                    matches.append(full_path)
+                elif not only_files and not only_dirs:
+                    matches.append(full_path)
+    if context:
+        matches = [match.format(**context) for match in matches]
+
+    return matches
 
 
 def get_reference_dir(packname):
@@ -37,7 +57,7 @@ def execute_shell_command(cmd, args=[]):
 
 def mega_find(basedir, pattern="*", maxdepth=999, mindepth=0, type_file='n'):
     basedir_len = len(basedir.split(os.sep))
-    res = find(basedir, pattern=pattern, only_files=type_file == 'f', only_dirs=type_file == 'd')
+    res = find_files_with_pattern(basedir, pattern=pattern, only_files=type_file == 'f', only_dirs=type_file == 'd')
     # filter by depth
     return list(filter(lambda x: basedir_len + mindepth <= len(x.split(os.sep)) <= maxdepth + basedir_len, res))
 
